# Zopper UUID Generator

This package will help in creating the uuid

## Formating
Formating using black

## Installation
### Command
```
pip install zopperuuid
```

For force reinstall

```
pip install --force-reinstall zopperuuid
```

## Usage
```
In [1]: from zopperuuid import uuid
In [2]: uuid.create_uuid()

Out[2]: 'zopper-d2c3a494-dc37-4c0f-aa87-31a6ea2dde23'
```